==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/ar/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => 'تسجيل <strong> الحساب </strong>',
  '<strong>Change</strong> Password' => '',
  '<strong>Change</strong> your password' => '<strong> تغيير </strong> كلمة مرورك',
  '<strong>Join</strong> the network' => '<strong> انضم </strong> إلى الشبكة',
  '<strong>Password</strong> changed!' => 'تم تغيير <strong> كلمة المرور </strong>!',
  '<strong>Password</strong> recovery' => 'استعادة <strong> كلمة المرور </strong>',
  '<strong>Password</strong> recovery!' => 'استعادة <strong> كلمة المرور </strong>!',
  '<strong>Please</strong> sign in' => '<strong> الرجاء </strong> تسجيل الدخول',
  '<strong>Registration</strong> successful!' => '<strong> التسجيل </strong> ناجح!',
  '<strong>Sign</strong> up' => '<strong> اشترك </strong>',
  '<strong>Your account</strong> has been successfully created!' => 'تم إنشاء <strong> حسابك </strong> بنجاح!',
  'Account' => 'الحساب',
  'After activating your account by the administrator, you will receive a notification by email.' => 'بعد تنشيط حسابك من قبل المسؤول ، ستتلقى إشعارًا عبر البريد الإلكتروني.',
  'Back' => 'عودة',
  'Change password' => 'غير كلمة السر',
  'Confirm' => 'أكد',
  'Create Account' => 'إنشاء حساب',
  'Create account' => 'إنشاء حساب',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'ليس لديك حساب؟ انضم إلى الشبكة بإدخال عنوان بريدك الإلكتروني.',
  'Due to security reasons you are required to change your password in order to access the platform.' => '',
  'Enter security code above' => 'أدخل رمز الحماية أعلاه',
  'Forgot your password?' => 'نسيت رقمك السري؟',
  'Go to login page' => 'انتقل إلى صفحة تسجيل الدخول',
  'Group' => 'مجموعة',
  'Hello {displayName}' => 'مرحبًا {displayName}',
  'Hello {displayName},' => 'مرحبًا {displayName} ،',
  'If you don\'t use this link within 24 hours, it will expire.' => 'إذا لم تستخدم هذا الرابط خلال 24 ساعة ، فستنتهي صلاحيته.',
  'If you\'re already a member, please login with your username/email and password.' => 'إذا كنت عضوًا بالفعل ، فيرجى تسجيل الدخول باستخدام اسم المستخدم / البريد الإلكتروني وكلمة المرور.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'فقط أدخل عنوان بريدك الإلكتروني. سنرسل لك تعليمات الاسترداد!',
  'Log out' => '',
  'Login' => 'تسجيل الدخول',
  'New user needs approval' => 'يحتاج المستخدم الجديد إلى موافقة',
  'Password recovery' => 'استعادة كلمة السر',
  'Password reset' => 'إعادة تعيين كلمة المرور',
  'Please check your email and follow the instructions!' => 'يرجى التحقق من بريدك الالكتروني واتبع التعليمات!',
  'Please click on the link below to view request:' => 'الرجاء الضغط على الرابط أدناه لعرض الطلب:',
  'Please enter the letters from the image.' => 'من فضلك أدخل الحروف من الصورة.',
  'Please login with your username/email and password.' => 'يرجى تسجيل الدخول باستخدام اسم المستخدم / البريد الإلكتروني وكلمة المرور.',
  'Please use the following link within the next day to reset your password.' => 'يرجى استخدام الرابط التالي في اليوم التالي لإعادة تعيين كلمة المرور الخاصة بك.',
  'Please wait' => '',
  'Register' => 'تسجيل',
  'Registration successful' => 'تم التسجيل بنجاح',
  'Remember me' => 'تذكرنى',
  'Reset Password' => 'إعادة تعيين كلمة المرور',
  'Reset password' => 'إعادة تعيين كلمة المرور',
  'Sign in' => 'تسجيل الدخول',
  'To log in with your new account, click the button below.' => 'لتسجيل الدخول باستخدام حسابك الجديد ، انقر فوق الزر أدناه.',
  'User or Password incorrect.' => '',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'لقد أرسلنا إليك بريدًا إلكترونيًا يحتوي على رابط يسمح لك بإعادة تعيين كلمة المرور الخاصة بك.',
  'Your email' => 'بريدك الالكتروني',
  'Your password' => 'كلمة المرور الخاصة بك',
  'Your password has been successfully changed!' => 'كلمة السر الخاصة بك تم تغييرها بنجاح!',
  'Your password is incorrect!' => 'كلمة المرور غير صحيحة',
  'a new user {displayName} needs approval.' => 'يحتاج المستخدم الجديد {displayName} إلى موافقة.',
  'back to home' => 'العودة إلى المنزل',
  'email' => 'البريد الإلكتروني',
  'password' => 'كلمه السر',
  'username or email' => 'اسم المستخدم أو البريد الالكتروني',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/user/messages/ar/auth.php <==
<?php
return array (
  '<strong>Account</strong> registration' => 'تسجيل <strong> الحساب </strong>',
  '<strong>Change</strong> Password' => '<strong>التغيير</strong>كلمة المرور',
  '<strong>Change</strong> your password' => '<strong> تغيير </strong> كلمة مرورك',
  '<strong>Join</strong> the network' => '<strong> انضم </strong> إلى الشبكة',
  '<strong>Password</strong> changed!' => 'تم تغيير <strong> كلمة المرور </strong>!',
  '<strong>Password</strong> recovery' => 'استعادة <strong> كلمة المرور </strong>',
  '<strong>Password</strong> recovery!' => 'استعادة <strong> كلمة المرور </strong>!',
  '<strong>Please</strong> sign in' => '<strong> الرجاء </strong> تسجيل الدخول',
  '<strong>Registration</strong> successful!' => 'لقد نجح<strong> التسجيل </strong> !',
  '<strong>Sign</strong> up' => '<strong> الاشتراك </strong>',
  '<strong>Your account</strong> has been successfully created!' => 'تم إنشاء <strong> حسابك </strong> بنجاح!',
  'Account' => 'الحساب',
  'After activating your account by the administrator, you will receive a notification by email.' => 'بعد تنشيط حسابك من قبل المسؤول ، ستتلقى إشعارًا عبر البريد الإلكتروني.',
  'Back' => 'عودة',
  'Change password' => 'تغيير كلمة السر',
  'Confirm' => 'تأكيد',
  'Create Account' => 'إنشاء حساب',
  'Create account' => 'إنشاء حساب',
  'Don\'t have an account? Join the network by entering your e-mail address.' => 'ليس لديك حساب؟ انضم إلى الشبكة بإدخال عنوان بريدك الإلكتروني.',
  'Due to security reasons you are required to change your password in order to access the platform.' => 'لأسباب الأمان أنت مطالب بتغيير كلمة مرورك لتتمكن من الدخول إلى المنصة.',
  'Enter security code above' => 'أدخل رمز الأمان أعلاه',
  'Forgot your password?' => 'هل نسيت كلمة المرور؟',
  'Go to login page' => 'انتقل إلى صفحة تسجيل الدخول',
  'Group' => 'مجموعة',
  'Hello {displayName}' => 'مرحبًا {displayName}',
  'Hello {displayName},' => 'مرحبًا {displayName} ،',
  'If you don\'t use this link within 24 hours, it will expire.' => 'إذا لم تستخدم هذا الرابط خلال 24 ساعة ، فستنتهي صلاحيته.',
  'If you\'re already a member, please login with your username/email and password.' => 'إذا كنت عضوًا بالفعل ، فيرجى تسجيل الدخول باستخدام اسم المستخدم / البريد الإلكتروني وكلمة المرور.',
  'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'فقط أدخل عنوان بريدك الإلكتروني. سنرسل لك تعليمات الاسترداد!',
  'Log out' => 'تسجيل الخروج',
  'Login' => 'تسجيل الدخول',
  'New user needs approval' => 'يحتاج المستخدم الجديد إلى موافقة',
  'Password' => 'كلمه المرور',
  'Password recovery' => 'استعادة كلمة السر',
  'Password reset' => 'إعادة تعيين كلمة المرور',
  'Please check your email and follow the instructions!' => 'يرجى التحقق من بريدك الالكتروني واتباع التعليمات!',
  'Please click on the link below to view request:' => 'الرجاء الضغط على الرابط أدناه لعرض الطلب:',
  'Please enter the letters from the image.' => 'من فضلك أدخل الحروف من الصورة.',
  'Please login with your username/email and password.' => 'يرجى تسجيل الدخول باستخدام اسم المستخدم / البريد الإلكتروني وكلمة المرور.',
  'Please use the following link within the next day to reset your password.' => 'يرجى استخدام الرابط التالي خلال اليوم التالي لإعادة تعيين كلمة المرور الخاصة بك.',
  'Please wait' => 'انتظر من فضلك',
  'Register' => 'الاشتراك',
  'Registration successful' => 'تم الاشتراك بنجاح',
  'Remember me' => 'تذكرني',
  'Reset Password' => 'إعادة تعيين كلمة المرور',
  'Reset password' => 'إعادة تعيين كلمة المرور',
  'Sign in' => 'تسجيل الدخول',
  'To log in with your new account, click the button below.' => 'لتسجيل الدخول باستخدام حسابك الجديد ، انقر على الزر أدناه.',
  'User or Password incorrect.' => 'اسم المستخدم أو كلمة المرور غير صحيحة',
  'Username or Email' => 'اسم المستخدم أو البريد الالكتروني',
  'We’ve sent you an email containing a link that will allow you to reset your password.' => 'لقد أرسلنا إليك بريدًا إلكترونيًا يحتوي على رابط يسمح لك بإعادة تعيين كلمة المرور الخاصة بك.',
  'Your email' => 'بريدك الالكتروني',
  'Your password' => 'كلمة المرور الخاصة بك',
  'Your password has been successfully changed!' => 'كلمة المرور الخاصة بك تم تغييرها بنجاح!',
  'Your password is incorrect!' => 'كلمة المرور غير صحيحة!',
  'a new user {displayName} needs approval.' => 'يحتاج المستخدم الجديد {displayName} إلى موافقة.',
  'back to home' => 'العودة إلى الصفحة الرئيسية',
);
